/*  VER 007  TAB P  $Id: sim.h,v 1.2.2.2 2003/01/21 08:59:18 egil Exp $
 *
 *  the simulated storage-API interface
 *
 *  $Log: sim.h,v $
 *  Revision 1.2.2.2  2003/01/21 08:59:18  egil
 *  Do not carry old INN storage.h
 *
 *  Revision 1.2.2.1  2002/02/06 20:11:35  egil
 *  Debian Bug#88795: newsx: Inn 2.3.1 storage API compilation
 *
 *  Revision 1.2  1999/04/05 10:56:31  src
 *  Have a copy of "storage.h" as a last resort since does not install
 *  this file by default. This is ugly...
 *
 *  Revision 1.1  1999/03/11 08:00:54  src
 *  Moved from storage
 *
 *  Revision 1.1  1999/03/07 14:58:24  src
 *  Storage API supported.
 */

#if HAVE_LIBSTORAGE
#if HAVE_INN_STORAGE_H
#    include <inn/storage.h>
#elif HAVE_STORAGE_H
#    include <storage.h>
#else
#    error "storage.h from INN distribution is really required"
#endif
#else
#  include "../lib/dummy.h" /* our own dummy */
#endif

ARTHANDLE * SIMretrieve(const char *name);
void SIMfreearticle(ARTHANDLE *article);
